@@ -95,16 +95,20 @@ void PackageKitBackend::acquireFetching(bool f)
 void PackageKitBackend::reloadPackageList()
 {
     m_updatingPackages = m_packages;
-    m_updatingTranslationPackageToApp = m_translationPackageToApp;
     
     if (m_refresher) {
         disconnect(m_refresher.data(), &PackageKit::Transaction::finished, this, &PackageKitBackend::reloadPackageList);
     }
 
     foreach(const Appstream::Component& component, m_appdata.allComponents()) {
-        m_updatingPackages[component.id()] = new AppPackageKitResource(component, this);
+        const auto res = new AppPackageKitResource(component, this);;
+        m_updatingPackages.packages[component.id()] = res;
         foreach (const QString& pkg, component.packageNames()) {
-            m_updatingTranslationPackageToApp[pkg] += component.id();
+            m_updatingPackages.packageToApp[pkg] += component.id();
+        }
+
+        foreach (const QString& pkg, component.extends()) {
+            m_updatingPackages.extendedBy[pkg] += res;
         }
     }
 
@@ -135,7 +139,7 @@ void PackageKitBackend::addPackage(PackageKit::Transaction::Info info, const QSt
     QVector<AbstractResource*> r = resourcesByPackageName(packageName, true);
     if (r.isEmpty()) {
         r += new PackageKitResource(packageName, summary, this);
-        m_updatingPackages[packageName] = r.last();
+        m_updatingPackages.packages[packageName] = r.last();
     }
     foreach(auto res, r)
         static_cast<PackageKitResource*>(res)->addPackageId(info, packageId, summary);
@@ -149,18 +153,17 @@ void PackageKitBackend::getPackagesFinished(PackageKit::Transaction::Exit exit)
         qWarning() << "error while fetching details" << exit;
     }
 
-    for(auto it = m_updatingPackages.begin(); it != m_updatingPackages.end(); ) {
+    for(auto it = m_updatingPackages.packages.begin(); it != m_updatingPackages.packages.end(); ) {
         auto pkr = qobject_cast<PackageKitResource*>(it.value());
         if (pkr->packages().isEmpty()) {
             qWarning() << "Failed to find package for" << it.key();
             it.value()->deleteLater();
-            it = m_updatingPackages.erase(it);
+            it = m_updatingPackages.packages.erase(it);
         } else
             ++it;
     }
 
     m_packages = m_updatingPackages;
-    m_translationPackageToApp = m_updatingTranslationPackageToApp;
     acquireFetching(false);
 }
 
@@ -178,8 +181,9 @@ void PackageKitBackend::packageDetails(const PackageKit::Details& details)
 
 QVector<AbstractResource*> PackageKitBackend::resourcesByPackageName(const QString& name, bool updating) const
 {
-    const QHash<QString, QStringList> *dictionary = updating ? &m_updatingTranslationPackageToApp : &m_translationPackageToApp;
-    const QHash<QString, AbstractResource*> *pkgs = updating ? &m_updatingPackages : &m_packages;
+    const Packages * const f = (updating ? &m_updatingPackages : &m_packages);
+    const QHash<QString, QStringList> *dictionary = &f->packageToApp;
+    const QHash<QString, AbstractResource*> *pkgs = &f->packages;
 
     const QStringList names = dictionary->value(name, QStringList(name));
     QVector<AbstractResource*> ret;
@@ -196,7 +200,7 @@ void PackageKitBackend::refreshDatabase()
 {
     if (!m_refresher) {
         m_refresher = PackageKit::Daemon::refreshCache(false);
-        connect(m_refresher, &PackageKit::Transaction::finished, this, &PackageKitBackend::reloadPackageList);
+        connect(m_refresher.data(), &PackageKit::Transaction::finished, this, &PackageKitBackend::reloadPackageList);
     } else {
         qWarning() << "already resetting";
     }
@@ -204,19 +208,19 @@ void PackageKitBackend::refreshDatabase()
 
 QVector<AbstractResource*> PackageKitBackend::allResources() const
 {
-    return m_packages.values().toVector();
+    return m_packages.packages.values().toVector();
 }
 
 AbstractResource* PackageKitBackend::resourceByPackageName(const QString& name) const
 {
-    const QStringList ids = m_translationPackageToApp.value(name, QStringList(name));
-    return ids.isEmpty() ? nullptr : m_packages[ids.first()];
+    const QStringList ids = m_packages.packageToApp.value(name, QStringList(name));
+    return ids.isEmpty() ? nullptr : m_packages.packages[ids.first()];
 }
 
 QList<AbstractResource*> PackageKitBackend::searchPackageName(const QString& searchText)
 {
     QList<AbstractResource*> ret;
-    Q_FOREACH (AbstractResource* res, m_packages.values()) {
+    Q_FOREACH (AbstractResource* res, m_packages.packages) {
         if (res->name().contains(searchText, Qt::CaseInsensitive)) {
             ret += res;
         }
@@ -254,14 +258,34 @@ void PackageKitBackend::addTransaction(PKTransaction* t)
     t->start();
 }
 
-void PackageKitBackend::installApplication(AbstractResource* app, AddonList )
+void PackageKitBackend::installApplication(AbstractResource* app, const AddonList& addons)
 {
-    installApplication(app);
+    if(!addons.addonsToInstall().isEmpty())
+    {
+        QVector<AbstractResource*> appsToInstall;
+
+        if(!app->isInstalled())
+            appsToInstall << app;
+
+        foreach(const QString& toInstall, addons.addonsToInstall()) {
+            appsToInstall += m_packages.packages.value(toInstall);
+            Q_ASSERT(appsToInstall.last());
+        }
+        addTransaction(new PKTransaction(appsToInstall, Transaction::ChangeAddonsRole));
+    }
+
+    if (!addons.addonsToRemove().isEmpty()) {
+        QVector<AbstractResource*> appsToRemove;
+        foreach(const QString& toRemove, addons.addonsToRemove()) {
+            appsToRemove += m_packages.packages.value(toRemove);
+        }
+        addTransaction(new PKTransaction(appsToRemove, Transaction::RemoveRole));
+    }
 }
 
 void PackageKitBackend::installApplication(AbstractResource* app)
 {
-    addTransaction(new PKTransaction(app, Transaction::InstallRole));
+    addTransaction(new PKTransaction({app}, Transaction::InstallRole));
 }
 
 void PackageKitBackend::cancelTransaction(AbstractResource* app)
@@ -282,7 +306,7 @@ void PackageKitBackend::cancelTransaction(AbstractResource* app)
 void PackageKitBackend::removeApplication(AbstractResource* app)
 {
     Q_ASSERT(!isFetching());
-    addTransaction(new PKTransaction(app, Transaction::RemoveRole));
+    addTransaction(new PKTransaction({app}, Transaction::RemoveRole));
 }
 
 QList<AbstractResource*> PackageKitBackend::upgradeablePackages() const
@@ -290,10 +314,11 @@ QList<AbstractResource*> PackageKitBackend::upgradeablePackages() const
     QVector<AbstractResource*> ret;
     Q_FOREACH (const QString& pkgid, m_updatesPackageId) {
         const QString pkgname = PackageKit::Daemon::packageName(pkgid);
-        ret += resourcesByPackageName(pkgname, false);
-        if (ret.isEmpty()) {
+        const auto pkgs = resourcesByPackageName(pkgname, false);
+        if (pkgs.isEmpty()) {
             qWarning() << "couldn't find resource for" << pkgid;
         }
+        ret += pkgs;
     }
     return ret.toList();
 }
@@ -360,6 +385,10 @@ QList<QAction*> PackageKitBackend::messageActions() const
     return m_messageActions;
 }
 
+QVector<AppPackageKitResource*> PackageKitBackend::extendedBy(const QString& id) const
+{
+    return m_packages.extendedBy[id];
+}
 
 //TODO
 AbstractReviewsBackend* PackageKitBackend::reviewsBackend() const { return nullptr; }
